@@ -12,7 +12,6 @@ from optuna.exceptions import DuplicatedStudyError
 import deepdriver
 from deepdriver import logger
 from deepdriver import util
-from deepdriver.intergration.torch.torch import set_torch_log, TorchLog, get_torch_log
 from deepdriver.sdk.config import Config
 from deepdriver.sdk.data_types.experiment import set_experiment, Experiment, get_experiment
 from deepdriver.sdk.data_types.run import set_run, Run, get_run
@@ -44,8 +43,8 @@ def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Di
                 )
     set_run(run)
 
-    # init pytoch Log
-    set_torch_log(TorchLog())
+    # init pytoch Log (delete for lazyload)
+    # set_torch_log(TorchLog())
 
     # init config
     deepdriver.config = Config()
@@ -126,8 +125,10 @@ def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_c
             func: Callable = None, count: int = 10, artifact: Dict = None, job_count: int = 0) -> bool:
     # assert_that(func).is_not_none()
 
-    result1, hpoConfig = get_hpo(exp_name=exp_name, team_name=team_name)
-    result2, study = load_hpo(exp_name=exp_name, team_name=team_name)
+    result1, hpoConfig, team_name_from_hpo = get_hpo(exp_name=exp_name, team_name=team_name)
+    if not result1:
+        raise Exception("HPO not found")
+    result2, study = load_hpo(exp_name=exp_name, team_name=team_name_from_hpo)
 
     if artifact:
         if not get_run():
@@ -141,7 +142,7 @@ def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_c
             if result:
                 hpoConfig['code_path'] = code_path
 
-    result3 = run_optimize(exp_name=exp_name, team_name=team_name, func=func, config=hpoConfig, count=count,
+    result3 = run_optimize(exp_name=exp_name, team_name=team_name_from_hpo, func=func, config=hpoConfig, count=count,
                            study=study)
 
     return True
@@ -197,17 +198,20 @@ def prepare_code(code: dict = None) -> Tuple[bool, str, Callable]:
 
 
 @util.login_required
-def get_hpo(exp_name: str = "", team_name: str = "") -> (bool, Dict):
+def get_hpo(exp_name: str = "", team_name: str = "") -> (bool, Dict, str):
     team_name_ = team_name or get_experiment().team_name
     rsp = interface.get_hpo(exp_name, team_name_)
-    return rsp['result'], rsp['hpoConfig']
+
+    if rsp['result'] == "success":
+        return True, rsp['hpoConfig'], rsp['teamName']
+    else:
+        return False, None, None
 
 
 @util.login_required
 def load_hpo(exp_name: str = "", team_name: str = "") -> (bool, optuna.study.study.Study):
-    team_name_ = team_name or get_experiment().team_name
     try:
-        study = optuna.load_study(study_name=team_name_ + "_" + exp_name,
+        study = optuna.load_study(study_name=team_name + "_" + exp_name,
                                   storage="postgresql://hpo:hpo@ce-postg.bokchi.com:5432/hpo")
     except Exception as e:
         logger.exception(e)
@@ -262,9 +266,9 @@ def run_optimize(exp_name: str = "", team_name: str = "", func: Callable = None,
 
         logger.debug(f"deepdriver.config. : {deepdriver.config.__dict__}")
 
-    team_name_ = team_name or get_experiment().team_name
+
     try:
-        study = study.optimize(get_wrapped_func(exp_name, team_name_, func, config), n_trials=count)
+        study = study.optimize(get_wrapped_func(exp_name, team_name, func, config), n_trials=count)
     except Exception as e:
         logger.exception(e)
         return False, None
